@@ -1,32 +1,14 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "akonaditaskrepository.h"
 
 #include <KLocalizedString>
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include "akonadicollectionfetchjobinterface.h"
 #include "akonadiitemfetchjobinterface.h"
@@ -51,7 +33,8 @@ KJob *TaskRepository::createItem(const Item &item)
     } else {
         auto job = new CompositeJob();
         CollectionFetchJobInterface *fetchCollectionJob = m_storage->fetchCollections(Akonadi::Collection::root(),
-                                                                                      StorageInterface::Recursive);
+                                                                                      StorageInterface::Recursive,
+                                                                                      this);
         job->install(fetchCollectionJob->kjob(), [fetchCollectionJob, item, job, this] {
             if (fetchCollectionJob->kjob()->error() != KJob::NoError)
                 return;
@@ -127,7 +110,7 @@ KJob *TaskRepository::update(Domain::Task::Ptr task)
 {
     auto item = m_serializer->createItemFromTask(task);
     Q_ASSERT(item.isValid());
-    return m_storage->updateItem(item);
+    return m_storage->updateItem(item, this);
 }
 
 KJob *TaskRepository::remove(Domain::Task::Ptr task)
@@ -136,7 +119,7 @@ KJob *TaskRepository::remove(Domain::Task::Ptr task)
     Q_ASSERT(item.isValid());
 
     auto compositeJob = new CompositeJob();
-    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(item);
+    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(item, this);
     compositeJob->install(fetchItemJob->kjob(), [fetchItemJob, compositeJob, this] {
         if (fetchItemJob->kjob()->error() != KJob::NoError)
            return;
@@ -144,7 +127,7 @@ KJob *TaskRepository::remove(Domain::Task::Ptr task)
         Q_ASSERT(fetchItemJob->items().size() == 1);
         auto item = fetchItemJob->items().at(0);
 
-        ItemFetchJobInterface *fetchCollectionItemsJob = m_storage->fetchItems(item.parentCollection());
+        ItemFetchJobInterface *fetchCollectionItemsJob = m_storage->fetchItems(item.parentCollection(), this);
         compositeJob->install(fetchCollectionItemsJob->kjob(), [fetchCollectionItemsJob, item, compositeJob, this] {
             if (fetchCollectionItemsJob->kjob()->error() != KJob::NoError)
                 return;
@@ -152,7 +135,7 @@ KJob *TaskRepository::remove(Domain::Task::Ptr task)
             Item::List childItems = m_serializer->filterDescendantItems(fetchCollectionItemsJob->items(), item);
             childItems << item;
 
-            auto removeJob = m_storage->removeItems(childItems);
+            auto removeJob = m_storage->removeItems(childItems, this);
             compositeJob->addSubjob(removeJob);
             removeJob->start();
         });
@@ -166,7 +149,7 @@ KJob *TaskRepository::promoteToProject(Domain::Task::Ptr task)
     auto item = m_serializer->createItemFromTask(task);
 
     auto job = new CompositeJob();
-    auto fetchJob = m_storage->fetchItem(item);
+    auto fetchJob = m_storage->fetchItem(item, this);
     job->install(fetchJob->kjob(), [fetchJob, job, this] {
         if (fetchJob->kjob()->error() != KJob::NoError)
            return;
@@ -175,7 +158,7 @@ KJob *TaskRepository::promoteToProject(Domain::Task::Ptr task)
         auto item = fetchJob->items().at(0);
         m_serializer->promoteItemToProject(item);
 
-        auto updateJob = m_storage->updateItem(item);
+        auto updateJob = m_storage->updateItem(item, this);
         job->addSubjob(updateJob);
         updateJob->start();
     });
@@ -187,7 +170,7 @@ KJob *TaskRepository::associate(Domain::Task::Ptr parent, Domain::Task::Ptr chil
     auto childItem = m_serializer->createItemFromTask(child);
 
     auto job = new CompositeJob();
-    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem);
+    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem, this);
     job->install(fetchItemJob->kjob(), [fetchItemJob, child, parent, job, this] {
         if (fetchItemJob->kjob()->error() != KJob::NoError)
            return;
@@ -198,7 +181,7 @@ KJob *TaskRepository::associate(Domain::Task::Ptr parent, Domain::Task::Ptr chil
 
         // Check collections to know if we need to move child
         auto partialParentItem = m_serializer->createItemFromTask(parent);
-        ItemFetchJobInterface *fetchParentItemJob = m_storage->fetchItems(partialParentItem.parentCollection());
+        ItemFetchJobInterface *fetchParentItemJob = m_storage->fetchItems(partialParentItem.parentCollection(), this);
         job->install(fetchParentItemJob->kjob(), [child, parent, fetchParentItemJob, partialParentItem, childItem, job, this] {
             if (fetchParentItemJob->kjob()->error() != KJob::NoError)
                 return;
@@ -232,14 +215,14 @@ KJob *TaskRepository::associate(Domain::Task::Ptr parent, Domain::Task::Ptr chil
             const int parentCollectionId = parentItem.parentCollection().id();
 
             if (itemCollectionId != parentCollectionId) {
-                ItemFetchJobInterface *fetchChildrenItemJob = m_storage->fetchItems(childItem.parentCollection());
+                ItemFetchJobInterface *fetchChildrenItemJob = m_storage->fetchItems(childItem.parentCollection(), this);
                 job->install(fetchChildrenItemJob->kjob(), [fetchChildrenItemJob, childItem, parentItem, job, this] {
                     if (fetchChildrenItemJob->kjob()->error() != KJob::NoError)
                         return;
 
                     Item::List childItems = m_serializer->filterDescendantItems(fetchChildrenItemJob->items(), childItem);
 
-                    auto transaction = m_storage->createTransaction();
+                    auto transaction = m_storage->createTransaction(this);
                     m_storage->updateItem(childItem, transaction);
                     childItems.push_front(childItem);
                     m_storage->moveItems(childItems, parentItem.parentCollection(), transaction);
@@ -247,7 +230,7 @@ KJob *TaskRepository::associate(Domain::Task::Ptr parent, Domain::Task::Ptr chil
                     transaction->start();
                 });
             } else {
-                auto updateJob = m_storage->updateItem(childItem);
+                auto updateJob = m_storage->updateItem(childItem, this);
                 job->addSubjob(updateJob);
                 updateJob->start();
             }
@@ -261,7 +244,7 @@ KJob *TaskRepository::dissociate(Domain::Task::Ptr child)
 {
     auto job = new CompositeJob();
     auto childItem = m_serializer->createItemFromTask(child);
-    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem);
+    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem, this);
     job->install(fetchItemJob->kjob(), [fetchItemJob, job, this] {
         if (fetchItemJob->kjob()->error() != KJob::NoError)
             return;
@@ -271,7 +254,7 @@ KJob *TaskRepository::dissociate(Domain::Task::Ptr child)
 
         m_serializer->removeItemParent(childItem);
 
-        auto updateJob = m_storage->updateItem(childItem);
+        auto updateJob = m_storage->updateItem(childItem, this);
         job->addSubjob(updateJob);
         updateJob->start();
     });
@@ -283,7 +266,7 @@ KJob *TaskRepository::dissociateAll(Domain::Task::Ptr child)
 {
     auto job = new CompositeJob();
     auto childItem = m_serializer->createItemFromTask(child);
-    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem);
+    ItemFetchJobInterface *fetchItemJob = m_storage->fetchItem(childItem, this);
     job->install(fetchItemJob->kjob(), [fetchItemJob, job, this] {
         if (fetchItemJob->kjob()->error() != KJob::NoError)
             return;
@@ -294,7 +277,7 @@ KJob *TaskRepository::dissociateAll(Domain::Task::Ptr child)
         m_serializer->removeItemParent(childItem);
         m_serializer->clearItem(&childItem);
 
-        auto updateJob = m_storage->updateItem(childItem);
+        auto updateJob = m_storage->updateItem(childItem, this);
         job->addSubjob(updateJob);
         updateJob->start();
     });
