@@ -1,25 +1,7 @@
-/* This file is part of Zanshin
-
-   Copyright 2014 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
-*/
+/*
+ * SPDX-FileCopyrightText: 2014 Kevin Ottens <ervin@kde.org>
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 
 #include "pageview.h"
@@ -218,6 +200,14 @@ PageView::PageView(QWidget *parent)
     filterViewAction->setCheckable(true);
     connect(filterViewAction, &QAction::triggered, this, &PageView::onFilterToggled);
 
+    auto doneViewAction = new QAction(this);
+    doneViewAction->setObjectName(QStringLiteral("doneViewAction"));
+    doneViewAction->setText(i18n("Show done tasks"));
+    doneViewAction->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-tasks")));
+    doneViewAction->setShortcut(Qt::CTRL | Qt::SHIFT | Qt::Key_D);
+    doneViewAction->setCheckable(true);
+    connect(doneViewAction, &QAction::triggered, m_filterWidget, &FilterWidget::setShowDoneTasks);
+
     auto futureViewAction = new QAction(this);
     futureViewAction->setObjectName(QStringLiteral("futureViewAction"));
     futureViewAction->setText(i18n("Show future tasks"));
@@ -227,6 +217,14 @@ PageView::PageView(QWidget *parent)
     connect(futureViewAction, &QAction::triggered, m_filterWidget, &FilterWidget::setShowFutureTasks);
 
     auto configGroup = KConfigGroup(KSharedConfig::openConfig(), "General");
+    if (configGroup.readEntry("ShowDone", true))
+        doneViewAction->trigger();
+
+    connect(doneViewAction, &QAction::triggered,
+            doneViewAction, [configGroup] (bool checked) mutable {
+                configGroup.writeEntry("ShowDone", checked);
+            });
+
     if (configGroup.readEntry("ShowFuture", true))
         futureViewAction->trigger();
 
@@ -247,6 +245,7 @@ PageView::PageView(QWidget *parent)
     m_actions.insert(QStringLiteral("page_view_remove"), removeItemAction);
     m_actions.insert(QStringLiteral("page_view_promote"), promoteItemAction);
     m_actions.insert(QStringLiteral("page_view_filter"), filterViewAction);
+    m_actions.insert(QStringLiteral("page_view_done"), doneViewAction);
     m_actions.insert(QStringLiteral("page_view_future"), futureViewAction);
     m_actions.insert(QStringLiteral("page_run_task"), m_runTaskAction);
 }
