@@ -1,26 +1,9 @@
-/* This file is part of Zanshin
-
-   Copyright 2015 Kevin Ottens <ervin@kde.org>
-
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+/*
+ * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
+ SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
+
 #include <testlib/qtest_zanshin.h>
 
 #include "akonadi/akonadilivequeryhelpers.h"
@@ -100,7 +83,7 @@ private slots:
         };
 
         // WHEN
-        auto fetch = helpers->fetchAllCollections();
+        auto fetch = helpers->fetchAllCollections(nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -172,7 +155,7 @@ private slots:
 
         // WHEN
         QFETCH(Akonadi::Collection, root);
-        auto fetch = helpers->fetchCollections(root);
+        auto fetch = helpers->fetchCollections(root, nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -249,7 +232,7 @@ private slots:
         };
 
         // WHEN
-        auto fetch = helpers->fetchItems();
+        auto fetch = helpers->fetchItems(nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -312,7 +295,7 @@ private slots:
 
         // WHEN
         QFETCH(Akonadi::Collection, collection);
-        auto fetch = helpers->fetchItems(collection);
+        auto fetch = helpers->fetchItems(collection, nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -399,7 +382,7 @@ private slots:
 
         // WHEN
         QFETCH(Domain::Context::Ptr, context);
-        auto fetch = helpers->fetchItemsForContext(context);
+        auto fetch = helpers->fetchItemsForContext(context, nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
@@ -472,7 +455,7 @@ private slots:
 
         // WHEN
         QFETCH(Akonadi::Item, item);
-        auto fetch = helpers->fetchSiblings(item);
+        auto fetch = helpers->fetchSiblings(item, nullptr);
         fetch(add);
         TestHelpers::waitForEmptyJobQueue();
 
